@@ -12,7 +12,7 @@ collectively contained in an LQCollection object. The key advantages of LoggedQu
 from os.path import join, dirname, expanduser
 from PyQt5 import QtCore, QtWidgets
 from numpy import nonzero
-from ..io.native import read_py4DSTEM, get_py4DSTEM_topgroups, get_py4DSTEM_version, get_N_dataobjects
+from py4DSTEM.io.native import read_py4DSTEM, get_py4DSTEM_topgroups, get_py4DSTEM_version, get_N_dataobjects
 import pyqtgraph as pg
 
 def datacube_selector(fp, data_id=0):
@@ -29,15 +29,15 @@ def datacube_selector(fp, data_id=0):
     # go through this in order to specifically get the first
     # datacube in a file...
     if (version_major, version_minor) == (0,12):
-        from ..io.native.read.read_utils_v0_12 import get_py4DSTEM_dataobject_info
+        from py4DSTEM.io.native.read.read_utils_v0_12 import get_py4DSTEM_dataobject_info
     elif (version_major, version_minor) == (0,9):
-        from ..io.native.read.read_utils_v0_9 import get_py4DSTEM_dataobject_info
+        from py4DSTEM.io.native.read.read_utils_v0_9 import get_py4DSTEM_dataobject_info
     elif (version_major, version_minor) == (0,7):
-        from ..io.native.read.read_utils_v0_7 import get_py4DSTEM_dataobject_info
+        from py4DSTEM.io.native.read.read_utils_v0_7 import get_py4DSTEM_dataobject_info
     elif (version_major, version_minor) == (0,6):
-        from ..io.native.read.read_utils_v0_6 import get_py4DSTEM_dataobject_info
+        from py4DSTEM.io.native.read.read_utils_v0_6 import get_py4DSTEM_dataobject_info
     elif (version_major, version_minor) == (0,5):
-        from ..io.native.read.read_utils_v0_5 import get_py4DSTEM_dataobject_info
+        from py4DSTEM.io.native.read.read_utils_v0_5 import get_py4DSTEM_dataobject_info
     else:
         raise Exception("This EMD file version is not supported by the GUI.")
 
