@@ -2,11 +2,12 @@ from py4DSTEM.process import virtualdiffraction
 from py4DSTEM.process import virtualimage
 from py4DSTEM.process import probe
 from py4DSTEM.process import diskdetection
-from py4DSTEM.process import dpc
+from py4DSTEM.process import latticevectors
+from py4DSTEM.process import phase
+from py4DSTEM.process import probe
 from py4DSTEM.process import calibration
 from py4DSTEM.process import utils
 from py4DSTEM.process import classification
 from py4DSTEM.process import latticevectors
 from py4DSTEM.process import diffraction
 
-#from . import rdf
