@@ -2,8 +2,8 @@
 
 import numpy as np
 from typing import Optional
-from ...io.datastructure import Calibration, PointListArray
-from ...utils.tqdmnd import tqdmnd
+from py4DSTEM.io.datastructure import Calibration, PointListArray
+from py4DSTEM.utils.tqdmnd import tqdmnd
 
 
 def get_Qvector_from_Rvector(vx, vy, QR_rotation):
