@@ -10,9 +10,9 @@ import cupyx.scipy.fft as cufft
 from time import time
 import numba
 
-from .kernels import kernels
-from ...io import PointList, PointListArray
-from ...utils.tqdmnd import tqdmnd
+from py4DSTEM.process.diskdetection.kernels import kernels
+from py4DSTEM.io import PointList, PointListArray
+from py4DSTEM.utils.tqdmnd import tqdmnd
 
 
 def find_Bragg_disks_CUDA(
